Alga
====

A command line utility for controlling a LG webOS TV over the network.

It is still in it's early stages of development but the implemented functionality should work.

Work yet to do:
---------------

* Add tests
* Add way of adding TV without having to set environment variables
* Add CI for running Ruff and Mypy
* Add CI for releasing versions to PyPI when tags are added
* Add support for Python versions besides 3.12
